<div align="center">
    <img width="200" src="https://raw.githubusercontent.com/nonebot/adapter-telegram/beta/docs/logo.png" alt="logo"></br>

# NoneBot Adapter Telegram

_✨ Telegram 协议适配 ✨_

</div>

## Manual

[使用指南](./MANUAL.md)

## Contributing

[贡献指南](./CONTRIBUTING.md)
